@@ -4,7 +4,7 @@ context("Google places details")
 test_that("language is valid", {
 
   expect_error(google_place_details(language = c("english", "french")),
-               "language must be a single character vector or string")
+               "language must be a single string")
 
 })
 
